import type { Knex } from "knex";

const TABLE = "filters";

export async function up(knex: Knex): Promise<void> {
    await knex.schema.createTable(TABLE, table => {
        table.increments("id").primary();
        table.string("guild_id").notNullable();
        table.string("name").notNullable();
        table.string("match").notNullable();
        table.enum("algorithm", [
            "any", "all", "exact",
            "regex", "fuzzy"
        ]).notNullable();
        table.boolean("is_insensitive").notNullable();
        table.boolean("is_whitelist").notNullable();
        table.timestamps(true, true);
    });
}


export async function down(knex: Knex): Promise<void> {
    await knex.schema.dropTableIfExists(TABLE);
}

