import { Request, Response } from "express";
import { buildDatatableQuery } from "@utils/datatable";
import { db } from "@db/db";
import { Filter } from "@db/models/filters.model";

const isPostgres = db.client.config.client === "pg";
const TABLE = "filters";

export const datatable = async (request: Request, response: Response) => {
    try {

        let query = db(TABLE).where({ guild_id: request.params.guildId });

        const datatableQuery = await buildDatatableQuery(request as any, query, TABLE);
        const { recordsTotal, recordsFiltered } = datatableQuery;
        const data = await datatableQuery.query;

        console.debug(`total: ${recordsTotal} filtered: ${recordsFiltered} filtered+paged: ${data.length}`);

        response.json({
            data,
            recordsFiltered,
            recordsTotal,
        });
    }
    catch (error) {
        console.error(error);
        response.status(500).json({ error: "Failed to fetch datatable for filters" });
    }
}

export const get = async (request: Request, response: Response) => {
    try {
        if (!request.query.id) {
            response.status(400).json({ error: "missing 'id' query" });
            return;
        }

        const data = await db("filters")
            .select("filters.*")
            .where({ "filters.id": request.query.id })
            .first();

        if (!data) {
            response.status(404).json({ message: "no result found" });
            return;
        }

        response.json(data);
    }
    catch (error) {
        console.error(error);
        response.status(500).json({ error: "Failed to fetch filter" });
    }
}

export const post = async (request: Request, response: Response) => {
    try {
        console.debug(JSON.stringify(request.body, null, 4));

        const guild_id = request.params.guildId;
        const { name, match, algorithm, is_insensitive, is_whitelist } = request.body;

        if (!name || !match || !algorithm) {
            response.status(400).json({ error: "Missing required fields" });
            return;
        }

        const [filter] = await db<Filter>(TABLE)
            .insert({
                guild_id,
                name,
                match,
                algorithm,
                is_insensitive: is_insensitive == "on",
                is_whitelist: is_whitelist == "on"
            })
            .returning("*");

            response.status(201).json(filter);
    }
    catch (error) {
        console.error(error);
        response.status(500).json({ error: "Failed to create Filter" });
    }
}

export default { datatable, get, post }
